@@ -1,9 +1,15 @@
+import os
+
+# Enable UTF-8 Mode for Windows
+# https://www.python.org/dev/peps/pep-0540/
+if os.name == "nt":
+    os.environ["PYTHONUTF8"] = "1"
+
 from typing import Optional
 from collections import OrderedDict
 from functools import wraps
 from pathlib import Path
 from multiprocessing import Process
-import os
 import signal
 import time
 import logging
@@ -1000,7 +1006,7 @@ def sync(
         remotedir,
         encrypt_key=encrypt_key,
         salt=salt,
-        encrypt_type=encrypt_type,
+        encrypt_type=getattr(EncryptType, encrypt_type),
         max_workers=max_workers,
         show_progress=not no_show_progress,
     )
